#[rustc_clean(label="hir_owner", cfg="rpass2")]
pub struct SomeType {
    pub x: u32,
    pub y: i64,
}
